/*
 * version 1.0j  (Sep 1989)
 * version 1.1j  (Dec 1989)
 * version 1.2j  (Dec 1989)
 * version 1.3j  (Jan 1990)
 * version 1.5j  (May 1991)
 * version 1.6j  (Oct 1991)
 * version 1.7j  (Dec 1991)
 * version 1.8j  (Dec 1992)
 * version 1.9j  (Jul 1994)
 * version 1.91j (Dec 1994)
 * version 2.0j-alpha  (Mar 1995)
 * version 2.0j-beta   (May 1996)
 * version 2.0j-gamma  (Dec 1996)
 * version 2.0j  (Jun 1997)
 * version 3.0j-alpha  (Aug 1998)
 * version 3.0j-beta   (Oct 1999)
 * version 3.0j  (Sep 2000)
 * version 3.1j  (Dec 2000)
 * version 3.2j  (Jan 2001)
 * version 4.0j  (Feb 2004)
 * version 4.1j  (Aug 2006)
 * version 4.2j  (Aug 2010)
 * version 5.0j  (Dec 2010)
 * version 5.1j  (Aug 2011)
 */

#include	"conf.h"

char *version = "@(#)dvi2ps (j-version) "PACKAGE_VERSION;
